<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/entity/RImageEntity.cpp" line="+90"/>
        <source>File</source>
        <translatorcomment>--exact match--
--file: locale_it_BKChem.po--
Caricamento File %1..
Caricamento File %1
&amp;File</translatorcomment>
        <translation>File</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+70"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: it.po--
Posizione della linea di quota o inserisci angolo:
Posizione della linea di quota o inserisci angolo
Specificare la posizione</translatorcomment>
        <translation>Posizione</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width Factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Fattore di larghezza</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height Factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Fattore di altezza</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width</source>
        <translatorcomment>--exact match--
--file: wp-geo-it_IT.po--
Larghezza:
Larghezza
&amp;Larghezza Carta:</translatorcomment>
        <translation>Larghezza</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height</source>
        <translatorcomment>--exact match--
--file: wp-geo-it_IT.po--
Altezza:
Altezza
Altezza Testo:</translatorcomment>
        <translation>Altezza</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Fade</source>
        <translation>Dissolvenza</translation>
    </message>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+88"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+76"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+115"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+107"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="+105"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="+104"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="+105"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="+103"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+91"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+79"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+89"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-18"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+76"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+82"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="-2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+106"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+77"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+88"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+77"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>X</source>
        <translatorcomment>--exact match--
--file: default.po--
Uscita dall&apos;applicazione...
Uscita dall&apos;applicazione
Esportazione Disegno...</translatorcomment>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-12"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-16"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: it.po--
Centro
Arco: Centro, Punto, Angoli
</translatorcomment>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="-1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-1"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-1"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-1"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Y</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Caricamento indirizzi delle librerie...
Caricamento indirizzi delle librerie
&amp;Modifica</translatorcomment>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Z</source>
        <translatorcomment>--exact match--
--file: src_shell_data_translations_ktoon_it.ts--
Affianca &amp;Orizzontalmente
Affianca Orizzontalmente
Congela tutto</translatorcomment>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Radius</source>
        <translatorcomment>--exact match--
--file: dia.master.it.po--
Raggio
Arco tangente alla base dell&apos;oggetto con raggio</translatorcomment>
        <translation>Raggio</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-9"/>
        <source>Start Angle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Angolo iniziale:
Angolo iniziale</translatorcomment>
        <translation>Angolo iniziale</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>End Angle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_it.ts--
Angolo finale o [Angolo/Lunghezza corda]
Angolo finale</translatorcomment>
        <translation>Angolo finale</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>Reversed</source>
        <translatorcomment>--exact match--
--file: qcadlib_it.ts--
Arcocomplementare</translatorcomment>
        <translation>Arcocomplementare</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+9"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+2"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+3"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+2"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+2"/>
        <source>Length</source>
        <translatorcomment>--exact match--
--file: locale_it_BKChem.po--
Lunghezza corda non valida
Angolo finale o [Angolo/Lunghezza corda]</translatorcomment>
        <translation>Lunghezza</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <source>Total Length</source>
        <translation>Lunghezza totale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sweep Angle</source>
        <translation>Angolo</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+2"/>
        <source>Total Area</source>
        <translation>Area totale</translation>
    </message>
    <message>
        <source>Contents</source>
        <translatorcomment>--exact match--
--file: assistant_it.ts--
Incolla il contenuto degli appunti
Modificare il contenuto del blocco selezionato</translatorcomment>
        <translation type="obsolete">Contenuti</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="-12"/>
        <source>Solid</source>
        <translatorcomment>--exact match--
--file: it.po--
Disegna Tratteggi e Riempimenti Pieni
Disegna Tratteggi e Riempimenti
Tratteggi / Riempimenti</translatorcomment>
        <translation>Solido</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Pattern</source>
        <translatorcomment>--exact match--
--file: Hatch_it.ts--
Modello
Modelli di Tratteggio:</translatorcomment>
        <translation>Modello</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Name</source>
        <translatorcomment>--exact match--
--file: locale_it_BKChem.po--
Documento senza nome %1
Salva Disegno con Nuovo Nome...
Salva Disegno con Nuovo Nome</translatorcomment>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>From Entity</source>
        <translation>Da entity</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+14"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+2"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <source>Angle</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Inserisci angolo:
Inserisci angolo
Inserisci l&apos;angolo della linea di quota:</translatorcomment>
        <translation>Angolo</translation>
    </message>
    <message>
        <location line="+192"/>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+17"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-191"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+2"/>
        <source>Scale</source>
        <translatorcomment>--exact match--
--file: locale_it_BKChem.po--
Scala</translatorcomment>
        <translation>Scala</translation>
    </message>
    <message>
        <source>Simple</source>
        <translatorcomment>--exact match--
--file: it.po--
Testo semplice
Esplode gli oggetti selezionati in oggetti piú semplice, o sottrae le facce</translatorcomment>
        <translation type="vanished">Semplice</translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="vanished">Testo</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation type="vanished">Testo normale</translation>
    </message>
    <message>
        <source>Font Name</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Nome del font</translation>
    </message>
    <message>
        <source>Text Height</source>
        <translation type="vanished">Altezza Testo</translation>
    </message>
    <message>
        <source>Text Angle</source>
        <translation type="vanished">Angolo testo</translation>
    </message>
    <message>
        <source>X Scale</source>
        <translation type="vanished">Scala X</translation>
    </message>
    <message>
        <source>Bold</source>
        <translatorcomment>--exact match--
--file: it3.po--
&amp;Grassetto
Grassetto
grassetto</translatorcomment>
        <translation type="vanished">Grassetto</translation>
    </message>
    <message>
        <source>Italic</source>
        <translatorcomment>--exact match--
--file: it3.po--
Old Italic
Cors&amp;ivo</translatorcomment>
        <translation type="vanished">Italico</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translatorcomment>--google--
Interasse linee:
Interasse Linee Pre&amp;definito
Interasse Linee Predefinito
Interlinea</translatorcomment>
        <translation type="vanished">Interasse linee</translation>
    </message>
    <message>
        <source>Alignment</source>
        <translatorcomment>--exact match--
--file: it.po--
Allineamento
Allineamento|Verticale</translatorcomment>
        <translation type="vanished">Allineamento</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Affianca &amp;Orizzontalmente
Affianca Orizzontalmente
&amp;Orizzontale</translatorcomment>
        <translation type="vanished">Orizzontale</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Verticale
&amp;Verticale</translatorcomment>
        <translation type="vanished">Verticale</translation>
    </message>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="-5"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <source>Diameter</source>
        <translatorcomment>--exact match--
--file: Scripts_it.ts--
Mostra simbolo diametro
ø (Diametro)</translatorcomment>
        <translation>Diametro</translation>
    </message>
    <message>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Circumference</source>
        <translatorcomment>--google--
Circonferenza:%1
Misura l&apos;area e la circonferenza di un poligono
Area/circonferenza</translatorcomment>
        <translation>Circonferenza</translation>
    </message>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+4"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <source>Area</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Area del tratteggio non valida. Controlla che gli oggetti scelti formino uno o più contorni chiusi.
Area del tratteggio non valida. Controlla che gli oggetti scelti formino uno o più contorni chiusi
Area Poligonale</translatorcomment>
        <translation>Area</translation>
    </message>
    <message>
        <location filename="../src/entity/REllipseEntity.cpp" line="-17"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Major Point</source>
        <translatorcomment>--google--
Punto principale|X
Punto principale|Y
Punto di maggiore dell&apos;ellisse o raggio principale</translatorcomment>
        <translation>Punto di maggiore</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ratio</source>
        <translatorcomment>--exact match--
--file: locale_it_BKChem.po--
Rapporto
Disegnare un arco ellittico dal centro, punto principale, il proporzione e gli angoli</translatorcomment>
        <translation>Rapporto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start Parameter</source>
        <translatorcomment>--ignored case--
--file: EllipseArcCPPA_it.ts--
Parametro di partenza</translatorcomment>
        <translation>Parametro iniziale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Parameter</source>
        <translatorcomment>--ignored case--
--file: EllipseArcCPPA_it.ts--
Parametro finale</translatorcomment>
        <translation>Parametro finale</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-7"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Point</source>
        <translatorcomment>--ignored case--
--file: it.po--
Punto iniziale (y):
Punto iniziale (y)
Punto iniziale (x):</translatorcomment>
        <translation>Punto iniziale</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Point</source>
        <translatorcomment>--ignored case--
--file: dia.master.it.po--
Punto finale (x):
Punto finale (x)
Punto finale (y):</translatorcomment>
        <translation>Punto finale</translation>
    </message>
    <message>
        <source>Clockwise</source>
        <translation type="vanished">Senso orario</translation>
    </message>
    <message>
        <source>Counterclockwise</source>
        <translation type="vanished">Senso antiorario</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-16"/>
        <source>Polyline Pattern</source>
        <translation>Modello polilinea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Closed</source>
        <translatorcomment>--exact match--
--file: SplineControlPoints_it.ts--
Area del tratteggio non valida. Controlla che gli oggetti scelti formino uno o più contorni chiusi.
Area del tratteggio non valida. Controlla che gli oggetti scelti formino uno o più contorni chiusi
Impossibile connettere alla polilinea chiusa.</translatorcomment>
        <translation>Chiuso</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Start Width</source>
        <translation>Larghezza iniziale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Width</source>
        <translation>Larghezza finale</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Width</source>
        <translation>Larghezza globale</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orientation</source>
        <translation>Orientamento</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Dimensioni</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Base Angle</source>
        <translation>Angolo di base</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Size 1</source>
        <translation>Dimensioni 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Size 2</source>
        <translation>Dimensioni 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Z</source>
        <translation>Z globale</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-21"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+2"/>
        <location line="+1"/>
        <source>Vertex</source>
        <translatorcomment>--google--
Prossimo vertice
Primo vertice
Aggiungi vertice</translatorcomment>
        <translation>Vertice</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-4"/>
        <source>Bulge</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Bulge</translation>
    </message>
    <message>
        <location filename="../src/entity/RSplineEntity.cpp" line="-12"/>
        <source>Closed Periodic</source>
        <translation>Chiuso periodica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translatorcomment>--exact match--
--file: Scripts_it.ts--
° (Gradi)
Gradi Decimali
Gradi decimali</translatorcomment>
        <translation>Gradi</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Control Point</source>
        <translatorcomment>--google--
Primo punto
Punto successivo o [%1]
Punto successivo</translatorcomment>
        <translation>Punto di controllo</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Fit Point</source>
        <translatorcomment>--google--
Primo punto di adattamento
Punto di adattamento successivo
&amp;Spline (punti di adattamento)</translatorcomment>
        <translation>Punto di adattamento</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Knot Vector</source>
        <translation>Vettore nodo</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Knot</source>
        <translation>Nodo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use Start Tangent</source>
        <translation>Utilizzare la tangente di inizio</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Tangent</source>
        <translation>Tangente iniziale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use End Tangent</source>
        <translation>Utilizzare la tangente finale</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Tangent</source>
        <translation>Tangente finale</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Line</source>
        <translatorcomment>--google--
Definisci posizione linea di quota
Inserisci l&apos;angolo della linea di quota:
Inserisci l&apos;angolo della linea di quota</translatorcomment>
        <translation>Linea di quota</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 1</source>
        <translatorcomment>--google--
Punto estensione 1|X
Punto estensione 1|Y</translatorcomment>
        <translation>Punto di estensione 1</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 2</source>
        <translatorcomment>--google--
Punto estensione 2|X
Punto estensione 2|Y</translatorcomment>
        <translation>Punto di estensione 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Linea 1 inizio</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 End</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Linea 1 fine</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Linea 2 inizio</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 End</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Linea 2 fine</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Arc</source>
        <translatorcomment>--google--
Posizione dell&apos;arco di quota
Posizione di arco di quota</translatorcomment>
        <translation>Arco di quota</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-6"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Chord Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punto di corda</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Far Chord Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Lontano punto di corda</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-5"/>
        <location line="+1"/>
        <source>Origin</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Origine della prima linea di estensione
Origine della seconda linea di estensione</translatorcomment>
        <translation>Origine</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate</source>
        <translatorcomment>--exact match--
--file: qcadactions_it.ts--
&amp;Ordinate
Ordinate
Valore dell&apos;ordinata</translatorcomment>
        <translation>Ordinate</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Defining Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punto di definizione</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Leader End Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Direttrice punto finale</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimRotatedEntity.cpp" line="+121"/>
        <source>Dimension Angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Angolo di quota</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-25"/>
        <source>Label</source>
        <translatorcomment>--exact match--
--file: dia.master.it.po--
 Etichetta:
Tornio
Inserisci una etichetta fissa o lascia vuoto per etichettatura automatica</translatorcomment>
        <translation>Etichetta</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Tolerance</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Tolleranza superiore
Tolleranza inferiore</translatorcomment>
        <translation>Tolleranza</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Upper Limit</source>
        <translatorcomment>--exact match--
--file: photivo_it.ts--
Limite superiore</translatorcomment>
        <translation>Limite superiore</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lower Limit</source>
        <translatorcomment>--exact match--
--file: photivo_it.ts--
Limite inferiore</translatorcomment>
        <translation>Limite inferiore</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Definition Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punto di definizione</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Posizione del testo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Flip First Arrow</source>
        <translation>Specchio la prima freccia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Flip Second Arrow</source>
        <translation>Specchio la seconda freccia</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Fixed Extension Line</source>
        <translation>Linea di prolunga fissa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension Line Length</source>
        <translation>Lunghezza linea di prolunga</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Auto Label</source>
        <translation>Auto etichetta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Measured Value</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Valore misurato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear Factor</source>
        <translation>Fattore</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block Name</source>
        <translation>Nome blocco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Auto Label Position</source>
        <translation>Auto Label Position</translation>
    </message>
    <message>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-4"/>
        <source>Arrow</source>
        <translatorcomment>--exact match--
--file: locale_it_BKChem.po--
Principale (linea con freccia)
Dimensione Freccia:</translatorcomment>
        <translation>Freccia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow Block</source>
        <translation>Freccia blocco</translation>
    </message>
    <message>
        <location filename="../src/entity/RFaceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 1</source>
        <translatorcomment>--google--
Punto estensione 1|X
Punto estensione 1|Y
Punto 1|X</translatorcomment>
        <translation>Punto 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 2</source>
        <translatorcomment>--google--
Punto estensione 2|X
Punto estensione 2|Y
Punto 2|X</translatorcomment>
        <translation>Punto 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 3</source>
        <translatorcomment>--google--
Punto 3|X
Punto 3|Y</translatorcomment>
        <translation>Punto 3</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 4</source>
        <translatorcomment>--google--
Punto 4|X
Punto 4|Y</translatorcomment>
        <translation>Punto 4</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeDefinitionEntity.cpp" line="+89"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+89"/>
        <source>Tag</source>
        <translation>Etichetta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prompt</source>
        <translation>Prompt</translation>
    </message>
    <message>
        <location filename="../src/entity/RRayEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Base Point</source>
        <translation>Punto base</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Second Point</source>
        <translation>Secondo punto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction Vector</source>
        <translation>Direzione</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+3"/>
        <source>Fixed Angle</source>
        <translation>Angolo fisso</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+1"/>
        <source>Invisible</source>
        <translation>Invisibile</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+141"/>
        <source>Arc Symbol Type</source>
        <translation>Simbolo arco</translation>
    </message>
</context>
</TS>
